# Copyright 2004 David Fifield

BUILD_HOST_TARGET =

ifneq ($(HOST),)
ifneq ($(BUILD),)
BUILD_HOST_TARGET += --build=$(BUILD)
endif
BUILD_HOST_TARGET += --host=$(HOST)
endif

export NODEPEND
builddep-$(GARDIR)/%: NODEPEND += $(NOBUILDDEPEND)

ifeq ($(findstring nls,$(USE)),)
DISABLE_NLS = --disable-nls
endif

GROUP = $(DESTDIR)$(sysconfdir)/group

# Override these with target-specific variable assignments.
GUSTO_GROUP_NAME = $*
GUSTO_GROUP_GID = 100
GUSTO_GROUP_MEMBERS =

# Create a new group.
# The format of a group entry is name:password:gid:members.
group-%: dep-$(GARDIR)/system/shadow
	@echo " ==> Creating group $(GUSTO_GROUP_NAME)"
	@grep -v "^$(GUSTO_GROUP_NAME):" $(GROUP) > $(GROUP).tmp || true
	@if cut -d : -f 3 $(GROUP).tmp | grep -q "^$(GUSTO_GROUP_GID)$$"; then \
		echo "*** GAR GAR GAR!  GID $(GUSTO_GROUP_GID) already exists in $(GROUP).  GAR GAR GAR! ***" 1>&2; \
		rm -f $(GROUP).tmp; \
		false; \
	fi
	@echo "$(GUSTO_GROUP_NAME):x:$(GUSTO_GROUP_GID):$(GUSTO_GROUP_MEMBERS)" >> $(GROUP).tmp
# Sort by GID.
	@sort -g -t : -k 3 $(GROUP).tmp > $(GROUP)
	@rm -f $(GROUP).tmp

PASSWD = $(DESTDIR)$(sysconfdir)/passwd

# Override these with target-specific variable assignments.
GUSTO_USER_NAME = $*
GUSTO_USER_UID = 1000
GUSTO_USER_GID = 100
GUSTO_USER_COMMENT =
GUSTO_USER_HOME = /home/$*
GUSTO_USER_SHELL =

# Create a new user.
# The format of a passwd entry is name:password:uid:gid:comment:home:shell.
user-%: dep-$(GARDIR)/system/shadow
	@echo " ==> Creating user $(GUSTO_USER_NAME)"
	@grep -v "^$(GUSTO_USER_NAME):" $(PASSWD) > $(PASSWD).tmp || true
	@if cut -d : -f 3 $(PASSWD).tmp | grep -q "^$(GUSTO_USER_UID)$$"; then \
		echo "*** GAR GAR GAR!  UID $(GUSTO_USER_UID) already exists in $(PASSWD).  GAR GAR GAR! ***" 1>&2; \
		rm -f $(PASSWD).tmp; \
		false; \
	fi
	@echo "$(GUSTO_USER_NAME):!:$(GUSTO_USER_UID):$(GUSTO_USER_GID):$(GUSTO_USER_COMMENT):$(GUSTO_USER_HOME):$(GUSTO_USER_SHELL)" >> $(PASSWD).tmp
# Sort by UID.
	@sort -g -t : -k 3 $(PASSWD).tmp > $(PASSWD)
	@rm -f $(PASSWD).tmp

install-source: checksum $(DESTDIR)$(sourcedir)
	-cp -Lu $(filter-out $(PARTIALDIR),$(addprefix $(DOWNLOADDIR)/,$(filter-out $(notdir $(wildcard $(FILEDIR)/*)),$(notdir $(wildcard $(DOWNLOADDIR)/*))))) $(DESTDIR)$(sourcedir)

# This is a crude way to see if there is a newer version of a package
# available. It fails on sites that don't provide a file listing and
# those that keep different versions in different directories, and with
# packages that manipulate $(GARVERSION) in DISTFILES.
check-for-new-version:
ifneq ($(MASTER_SITES),)
	@for site in $(MASTER_SITES); do \
		wget -nc -q -t 1 -T 10 $$site; \
		for file in $(filter-out $(shell ls $(FILEDIR) 2>/dev/null),$(DISTFILES)); do \
			VERSION=`echo $(GARVERSION) | sed -e 's/\./\./g'`; \
			if [ ! `echo $$file | grep "$$VERSION"` ]; then \
				echo "Can't check for a new version of $$file."; \
				continue; \
			fi; \
			PREFIX=`echo $$file | sed -e "s/$$VERSION.*//" -e 's/\./\./g'`; \
			SUFFIX=`echo $$file | sed -e "s/.*$$VERSION//" -e 's/\./\./g'`; \
			NEWEST=`grep "$$PREFIX.*$$SUFFIX" index.html | sed -e "s/.*$$PREFIX\(.*\)$$SUFFIX.*/\1/" | sort -n -r -t . -k 1,1 -k 2,2 -k 3,3 -k 4,4 | head -n 1`; \
			if [ -z "$$NEWEST" ]; then \
				echo "$$site$$file not found."; \
			elif [ -n "$$NEWEST" -a "$$NEWEST" != $(GARVERSION) ]; then \
				echo "$$site$$PREFIX$$NEWEST$$SUFFIX"; \
			fi; \
		done; \
		rm -f index.html; \
	done
endif
	@true
